@@ -23,8 +23,11 @@ def get_form_spec(form: DjangoForm) -> FormState:
     hidden_fields = []
     for name, bound_field in bound_fields.items():
         field = bound_field.field
+        field_name = field.dfp_field_name if hasattr(field, 'dfp_field_name') else type(field).__name__
+
         widget = bound_field.field.widget
-        widget_type = type(widget)
+        widget_name = widget.dfp_widget_name if hasattr(widget, 'dfp_widget_name') else type(widget).__name__
+
         field_spec = {
             'name': name,
             'label': str(field.label),
@@ -45,6 +48,10 @@ def get_form_spec(form: DjangoForm) -> FormState:
         elif field.initial:
             field_spec['initial'] = field.initial
 
+        # hotfix for DateInput
+        if widget_name == 'DateInput':
+            field_spec['initial'] = widget.format_value(form.initial[name])
+
         # Error messages (i18n)
         # TODO unify the logic
         global_messages = get_global_error_messages()
@@ -63,7 +70,6 @@ def get_form_spec(form: DjangoForm) -> FormState:
         # Validators
         field_spec['validators'] = []
         has_custom_validators = hasattr(helper, 'validators')
-        field_name = field.dfp_field_name if hasattr(field, 'dfp_field_name') else type(field).__name__
         match field_name:
             case 'CharField':
                 if hasattr(field, 'max_length') and field.max_length:
@@ -84,6 +90,7 @@ def get_form_spec(form: DjangoForm) -> FormState:
                     'type': validator['type'] if 'type' in validator else validator['name'],
                     'value': validator['value'],
                     'inverse': validator['inverse'] if 'inverse' in validator else False,
+                    'allow_empty': validator['allow_empty'] if 'allow_empty' in validator else False,
                     'message': str(validator['message']) if 'message' in validator else None,
                 }
                 field_spec['validators'].append(cur_validator)
@@ -103,25 +110,29 @@ def get_form_spec(form: DjangoForm) -> FormState:
                     'type': validator['type'] if 'type' in validator else validator['name'],
                     'value': validator['value'] if 'value' in validator else None,
                     'inverse': validator['inverse'] if 'inverse' in validator else False,
+                    'allow_empty': validator['allow_empty'] if 'allow_empty' in validator else False,
                     'message': str(validator['message']),  # a message is required for now
                 })
 
         # attr: type  + specific settings
-        widget_name = widget_type.__name__
         match widget_name:
             case 'SlugInput':
                 field_spec['type'] = 'slug'
                 field_spec['prefix'] = widget.prefix if hasattr(widget, 'prefix') else ''
-                field_spec['suggestions'] = widget.suggestions
+                field_spec['suggestions'] = widget.suggestions if hasattr(widget, 'suggestions') else []
                 default_initial = ''
             case 'TextInput':
                 field_spec['type'] = 'text'
+                field_spec['input_format'] = widget.input_format if hasattr(widget, 'input_format') else ''
                 default_initial = ''
             case 'NumberInput':
                 field_spec['type'] = 'number'
             case 'EmailInput':
                 field_spec['type'] = 'email'
                 default_initial = ''
+            case 'DateInput':
+                field_spec['type'] = 'date'
+                default_initial = ''
             case 'Textarea':
                 field_spec['type'] = 'textarea'
                 default_initial = ''
@@ -149,7 +160,7 @@ def get_form_spec(form: DjangoForm) -> FormState:
                 field_spec['type'] = 'captcha'
                 default_initial = ''
             case _:
-                raise ValueError(f'Unknown widget type: {widget_type.__name__}')
+                raise ValueError(f'Unknown widget type: {widget_name}')
 
         # null is a bad initial value for react-hook-form
         # it consider an empty input with required=False as invalid if it has initial=null
@@ -214,6 +225,8 @@ def _get_fieldsets_spec(meta, fields_spec: dict) -> list:
 def _transform_fieldset_fields(fields: list) -> list:
     result = []
     for field in fields:
+        # TODO raise if field is not in fields list
+        #      it will require to transform get_form_spec() to a class
         if isinstance(field, LayoutItem):
             field_spec = field.to_spec()
         else:
